summaryrefslogtreecommitdiff
path: root/src/lib/video_decoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-12-13 10:23:20 +0000
committerCarl Hetherington <cth@carlh.net>2013-12-13 10:23:20 +0000
commitda19eaac0dd80afed3dd282d61ea3298196a5090 (patch)
tree8b6caca26fc79aa943082965e7aac72ae6dcc521 /src/lib/video_decoder.h
parent097a1fb413bbbb89182161d4c1a31daa5419ec96 (diff)
Start of changing frame numbers to time.
Diffstat (limited to 'src/lib/video_decoder.h')
-rw-r--r--src/lib/video_decoder.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/lib/video_decoder.h b/src/lib/video_decoder.h
index 01319e481..6e9060dbd 100644
--- a/src/lib/video_decoder.h
+++ b/src/lib/video_decoder.h
@@ -38,15 +38,14 @@ public:
* First parameter is the video image.
* Second parameter is the eye(s) which should see this image.
* Third parameter is true if the image is the same as the last one that was emitted for this Eyes value.
* Fourth parameter is the frame within our source.
*/
- boost::signals2::signal<void (boost::shared_ptr<const Image>, Eyes, bool, VideoContent::Frame)> Video;
+ boost::signals2::signal<void (boost::shared_ptr<const Image>, Eyes, bool, ContentTime)> Video;
protected:
- void video (boost::shared_ptr<const Image>, bool, VideoContent::Frame);
+ void video (boost::shared_ptr<const Image>, bool, ContentTime);
boost::shared_ptr<const VideoContent> _video_content;
- VideoContent::Frame _video_position;
};
#endif
@@ -38,15 +38,14 @@ public:
* Second parameter is the eye(s) which should see this image.
* Third parameter is true if the image is the same as the last one that was emitted for this Eyes value.
- * Fourth parameter is the frame within our source.
+ * Fourth parameter is the time within our source.
*/